"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.HiDpiPicture = HiDpiPicture;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _util = require("../util");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function srcSetAttr(bp, widths, dppx, config, src) {
  var imageHeight = dppx * bp.height;
  var query = "".concat(bp.op.includes('?') ? '&' : '?', "dppx=").concat(dppx, "&auth=").concat(config.apiKey);
  var scheme = config.domain.includes('//') ? '' : '//';
  return widths.reduce(function (srcSet, w) {
    var imageWidth = w * dppx;
    var op = "".concat(bp.op.replace('{WIDTH}', imageWidth).replace('{HEIGHT}', imageHeight));
    return "".concat(srcSet).concat(srcSet.length !== 0 ? ',' : '').concat(scheme).concat(config.domain, "/api/2/img/").concat((0, _util.prepareSource)(src), "/").concat(op).concat(query, " ").concat(imageWidth, "w");
  }, '');
}
function sizesAttr(sizesConfig, config) {
  return Object.keys(sizesConfig).
  // A breakpoint without media query must go last
  sort(function (bp1, bp2) {
    var media1 = config.breakpoints[bp1]['media'];
    var media2 = config.breakpoints[bp2]['media'];
    if (!media1) {
      return 1;
    }
    if (!media2) {
      return -1;
    }
    return 0;
  }).reduce(function (sizesAcc, bpKey) {
    var newSizes = sizesAcc;
    if (newSizes.length > 0) {
      newSizes += ', ';
    }
    var mediaQuery = config.breakpoints[bpKey]['media'];
    if (mediaQuery) {
      newSizes += "".concat(mediaQuery, " ");
    }
    newSizes += sizesConfig[bpKey];
    return newSizes;
  }, '');
}
function HiDpiPicture(_ref) {
  var src = _ref.src,
    alt = _ref.alt,
    config = _ref.config,
    breakpoints = _ref.breakpoints,
    minWidth = _ref.minWidth,
    maxWidth = _ref.maxWidth,
    imgProps = _ref.imgProps,
    lazy = _ref.lazy,
    sizes = _ref.sizes;
  var widths = [];
  for (var s = minWidth; s < maxWidth;) {
    widths.push(s);
    if (s < 1000) {
      s += 100;
    } else {
      s += 200;
    }
    if (s > maxWidth) {
      s = maxWidth;
    }
  }
  widths.push(maxWidth);
  return /*#__PURE__*/_react["default"].createElement("picture", null, Object.keys(breakpoints).map(function (bpKey) {
    var bpConfig = config.breakpoints[bpKey];
    var bp = breakpoints[bpKey];
    if (!bpConfig) {
      throw new Error("could not find breakpoint [".concat(bpKey, "] in the config"));
    }
    var bpConfigMedia = '';
    if (bpConfig.media) {
      bpConfigMedia = " and ".concat(bpConfig.media);
    }
    return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, {
      key: "".concat(src).concat(bpKey)
    }, /*#__PURE__*/_react["default"].createElement("source", {
      media: "(-webkit-min-device-pixel-ratio: 2) and (-webkit-max-device-pixel-ratio: 2.9999)".concat(bpConfigMedia),
      srcSet: srcSetAttr(bp, widths, 2, config, src),
      sizes: sizesAttr(sizes, config)
    }), /*#__PURE__*/_react["default"].createElement("source", {
      media: "(-webkit-min-device-pixel-ratio: 3)".concat(bpConfigMedia),
      srcSet: srcSetAttr(bp, widths, 3, config, src),
      sizes: sizesAttr(sizes, config)
    }), /*#__PURE__*/_react["default"].createElement("source", {
      media: "(-webkit-min-device-pixel-ratio: 1) and (-webkit-max-device-pixel-ratio: 1.9999)".concat(bpConfigMedia),
      srcSet: srcSetAttr(bp, widths, 1, config, src),
      sizes: sizesAttr(sizes, config)
    }));
  }), /*#__PURE__*/_react["default"].createElement("img", _extends({
    alt: alt,
    src: (0, _util.prepareSource)(src)
  }, imgProps, lazy && {
    loading: 'lazy'
  })));
}
HiDpiPicture.propTypes = {
  src: _propTypes["default"].string.isRequired,
  alt: _propTypes["default"].string.isRequired,
  config: _propTypes["default"].object.isRequired,
  breakpoints: _propTypes["default"].objectOf(_propTypes["default"].shape({
    op: _propTypes["default"].string.isRequired,
    height: _propTypes["default"].number
  })).isRequired,
  minWidth: _propTypes["default"].number.isRequired,
  maxWidth: _propTypes["default"].number.isRequired,
  imgProps: _propTypes["default"].object,
  lazy: _propTypes["default"].bool,
  sizes: _propTypes["default"].objectOf(_propTypes["default"].string.isRequired)
};